@@ -1,10 +1,10 @@
 
 use strict;
-use v5.6.0;
+use 5.006;
 
 package Mail::Box::Mbox;
 our @ISA     = 'Mail::Box';
-our $VERSION = v0.6;
+our $VERSION = v0.7;
 
 use Mail::Box;
 
@@ -964,7 +964,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is alpha, version 0.6
+This code is alpha, version 0.7
 
 =cut
 
