@@ -2,9 +2,9 @@
 package Mail::Box::Tie;
 
 use strict;
-use v5.6.0;
+use 5.006;
 
-our $VERSION = '0.6';
+our $VERSION = '0.7';
 
 =head1 NAME
 
@@ -129,7 +129,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is alpha, version 0.6
+This code is alpha, version 0.7
 
 =cut
 
